/*******************************************************************************
 * $Id: omnistat.h 206 2008-08-01 21:44:50Z msiegen $
 *
 * Thermostat Serial Interface
 *
 * by Michael Siegenthaler
 * http://www.msigi.net/
 *
 * THIS SOFTWARE IS PUBLIC DOMAIN AND IS PROVIDED WITHOUT ANY WARRANTY
 *
 ******************************************************************************/

// Address of thermostat
#ifndef TSTAT_ADDR
  #define TSTAT_ADDR 1
#endif

// Maximum number of retries for commands
#ifndef MAX_RETRIES
  #define MAX_RETRIES 4
#endif

int query(char* outbuf, int outlen, char* inbuf, int in_maxlen);

int readreg(int regnum);

int writereg(int regnum, int value);

int setclock(void);

struct group1_data {
  int unit;   // unit for temperatures
  int coolpoint; // cool setpoint
  int heatpoint; // heat setpoint
  int mode;   // mode
  int fan;    // fan status
  int hold;   // hold status
  int actual; // current temperature
};

int poll_group1(int unit, struct group1_data* data);

// Temperature conversions
int o_to_c(int dego);
int c_to_o(int degc);
int o_to_f(int dego);
int f_to_o(int degf);

#define MODE_OFF 0
#define MODE_HEAT 1
#define MODE_COOL 2
#define MODE_AUTO 3

int set_mode(int mode);
int get_mode(void);

char* mode_text(int num);
int mode_num(char* text);

#define FAN_AUTO 0
#define FAN_ON 1

int set_fan(int fan);
int get_fan(void);

char* fan_text(int num);
int fan_num(char* text);

#define HOLD_OFF 0
#define HOLD_ON 255

int set_hold(int hold);
int get_hold(void);

char* hold_text(int num);
int hold_num(char* text);

int get_filter(void);
int get_current_runtime(void);
int get_last_runtime(void);
int get_output_status(void);

#define DEG_O 0
#define DEG_C 1
#define DEG_F 2

int set_heatpoint(int value, int unit);
int get_heatpoint(int unit);
int set_coolpoint(int value, int unit);
int get_coolpoint(int unit);

int set_outside(int value, int unit);
int get_actual(int unit);

int set_some_temp(int regnum, int value, int unit);
int get_some_temp(int regnum, int unit);

int text_to_unit(char* text);
char* unit_to_text(int unit);
